// Nastavenie veľkosti typografického bodu
// (c) JP, verzia 2014.11.23
//
// Stručná história typografického bodu
//
// Typografický bod bol prvýkrát definovaný vo Francúzsku. Pre jeho vývoj je dôležité,
// že v roku 1668 boli reformované dĺžkové miery (reformy prevádzal Jean-Baptiste Colbert) –
// Kráľovská stopa a z nej odvodená novo-rímska stopa (11 palcov Kráľovskej stopy).
//
// Koncom 17. storočia ako prvý definoval typografický bod duchovný Sébastien Truchet (1657–1729)
// a to ako 1/1728 (1728=12^3) Kráľovskej stopy (0,18798575519 mm).
// http://en.wikipedia.org/wiki/Point_(typography)
//
// Pierre Simon Fournier (1712–1768) v Manuel Typographique (1764) definoval typografický
// bod ako 1/144 dvoch palcov, t.j. ako 1/864 (864=12x12x6) novo-rímskej stopy (0,34464055118426 mm).
// http://jacques-andre.fr/ed/FournierI-P.pdf (str. 127–140)
//
// François Ambroise Didot (1730–1801) sa v roku 1774 vrátil k Truchetovmu systému
// a definoval typografický bod ako 1/864 Kráľovskej stopy (0,37597151038 mm).
// V roku 1790 bol vo Francúzsku zavedený metrický systém a zákonom bol definovaný meter
// ako 443,296 násobok Francúzskeho riadka, z čoho vyplýva z neho odvodená Kráľovská stopa
// ako 9000/27706 metrov (32,4839384971 cm). Týmto dokážeme presne vypočítať aj Truchetov, Fournierov
// či Didotov typografický bod, ktoré boli definované ešte pred zavedením metrického systému.
// Didot však po zavedení metrického systému zaokrúhlil počet bodov na jeden meter (dovtedy 2659,776)
// a typografický bod určil ako 1/2660 metra (0,3759398496 mm). Tento systém sa následne
// začal používať takmer v celej kontinentálnej Európe a používa sa, ako to vyplýva
// aj z viacerých internetových diskusií, napriek presadzovanému „počítačovému“
// americkému systému doteraz. Aj z tohto dôvodu InDesign umožňuje o. i. zadávať veľkosti
// v Cicerách, pričom 1 Cicero počíta podľa Didotovho systému ako 12 bodov veľkých 1/2660 metra.
// Z Fournierovho systému zostalo názvoslovie stupňov písma, aj keď v tomto smere je to
// mierne kuriózne, pretože napr. pôvodné Fournierove Cicero má cca 11 (presnejšie 11,001)
// Didotových bodov a, naopak, Didotovo Cicero má cca 13 (presnejšie 13,09) Fournierových bodov.
// http://fr.wikipedia.org/wiki/Point_(unit%C3%A9)
// http://fr.wikipedia.org/wiki/Pied_(unit%C3%A9)
// http://fr.wikipedia.org/wiki/Anciennes_unit%C3%A9s_de_mesure_fran%C3%A7aises 
//
// V Habsburskej monarchii bol v roku 1840 zavedený systém pražského rodáka Bohumila Haasa.
// Vychádzal z Rakúskej stopy (31,60806 cm), čo je 12 českých palcov (2,63401 cm).
// Typografický bod určil rozdelením českého palca na 36 štvrťpetit dielov (0,365834722... mm).
// V roku 1879 Hermann Berthold zjednotil nemecký typografický systém, pričom zaviedol
// Didotov systém.
// http://cs.wikipedia.org/wiki/Typografick%C3%BD_bod
// http://www.typolexikon.de/b/berthold-hermann.html
//
// Anglosaský systém vychádza z „metrického“ Fournierovho bodu (tento Fournierov bod
// veľký 0,35mm sa spomína napr. vo francúzskom Bulletin typographique č. 18 z 1. februára 1844)
// a typografický bod definuje ako 1/72,27 anglického palca (0,3514598035146 mm).
//
// Po zavedení počítačového spracovania Adobe a iné programy zaokrúhlili anglosaský
// systém a definujú typografický bod ako 1/72 anglického palca (0,35277... mm).
//
// V InDesign sa nastavuje veľkosť bodu ako "počet bodov na palec" (samozrejme, anglický palec).
// Vnútorne však InDesign robí mnohé výpočty s hodnotou 72 bodov na palec a preto je potrebné
// v skriptoch prepínať na tento systém a potom vracať nastavenia na používateľpom definovanú hodnotu!
//
var vDokumente=(app.documents.length != 0); //Či je otvorený nejaký dokument
var BodovNaPalec=72; //Štandardne nastavujeme Adobe 72 bodov na palec
var NazovBodu="Adobe";
var IDAktualneBody=app.viewPreferences.pointsPerInch;
var AktualneBody=app.viewPreferences.pointsPerInch;
if (vDokumente==true) {
 AktualneBody=app.activeDocument.viewPreferences.pointsPerInch;
}
var AktualnySystem=0;
if (AktualneBody==72) {AktualnySystem=0;} //Adobe systém (bod 0,35277... mm)
else { 
 if (AktualneBody==72.27) {AktualnySystem=1;} //Anglosaský systém (bod 0,35145980351460 mm)
 else{
  if (AktualneBody==67.564) {AktualnySystem=2;} //Didot (bod 0,37593984962406 mm)
  else {
   if (AktualneBody==67.5583104) {AktualnySystem=3;} //Didot [18. storočie] (bod 0,375971510382829 mm)
   else {
    if (AktualneBody==73.6999749818182) {AktualnySystem=4;} //Fournier (bod 0,34464055118426 mm)
    else {
     if (AktualneBody==69.4302603255113) {AktualnySystem=5;} //Haas ( bod 0,365834722... mm)
     else {AktualnySystem=6;} //Iné nastavenie
    }
   }   
  }
 }
}
try {
 app.viewPreferences.pointsPerInch=72;
 app.activeDocument.viewPreferences.pointsPerInch=72;
 } 
 catch (e) {}
var DialogNastavBody=app.dialogs.add({name:"Nastavenie veľkosti typografického bodu"});
with(DialogNastavBody.dialogColumns.add()){
 with(dialogRows.add()){
  with(dialogColumns.add()){
   staticTexts.add({staticLabel:"Nastaviť v:"});
  }
  with(dialogColumns.add()){
   with(borderPanels.add()){
    with(dialogColumns.add()){
     var NastavID=checkboxControls.add({staticLabel:"Globálne v InDesign", checkedState:true});
     if (vDokumente==true) {
      var NastavDokument=checkboxControls.add({staticLabel:"V aktuálnom dokumente", checkedState:true});
     }
    }
   }
  }
 }
 with(dialogRows.add()){
  with(dialogColumns.add()){
   staticTexts.add({staticLabel:"Typografický bod:"});
   staticTexts.add({staticLabel:" "});
   staticTexts.add({staticLabel:" "});
   staticTexts.add({staticLabel:" "});
   staticTexts.add({staticLabel:" "});
   staticTexts.add({staticLabel:" "});
   var InyTypoBod=measurementEditboxes.add({editValue:AktualneBody, editUnits:MeasurementUnits.POINTS});
  }
  var MoznostiBodov = radiobuttonGroups.add();
  with(MoznostiBodov){
   radiobuttonControls.add({staticLabel:"Adobe (72 bodov/palec)", checkedState:(AktualnySystem==0)});
   radiobuttonControls.add({staticLabel:"Anglosaský (72,27 bodov/palec)", checkedState:(AktualnySystem==1)});
   radiobuttonControls.add({staticLabel:"Didotov (67,564 bodov/palec)", checkedState:(AktualnySystem==2)});
   radiobuttonControls.add({staticLabel:"Didotov prvotný [18. storočie] (67,5583104 bodov/palec)", checkedState:(AktualnySystem==3)});
   radiobuttonControls.add({staticLabel:"Fournierov (73,6999749818182 bodov/palec)", checkedState:(AktualnySystem==4)}); 
   radiobuttonControls.add({staticLabel:"Haasov (69,4302603255113 bodov/palec)", checkedState:(AktualnySystem==5)});
   radiobuttonControls.add({staticLabel:"Iný (zadajte počet [60–80] bodov/palec)", checkedState:(AktualnySystem==6)});
  }
 }
}
var dialogOK=DialogNastavBody.show();
try {
 app.viewPreferences.pointsPerInch=IDAktualneBody;
 app.activeDocument.viewPreferences.pointsPerInch=AktualneBody;
 } 
 catch (e) {}
if(dialogOK==true){
 switch(MoznostiBodov.selectedButton){
  case 0:
   BodovNaPalec=72; // Adobe systém
   NazovBodu="Adobe";
   break;
  case 1:
   BodovNaPalec=72.27; // Anglosaský systém
   NazovBodu="Anglosaský";
   break;
  case 2:
   BodovNaPalec=67.564; // Didotov metrický systém
   NazovBodu="Didotov";
   break;
  case 3:
   BodovNaPalec=67.5583104; // Didot prvotný [18. storočie] systém
   NazovBodu="Didotov prvotný [18. storočie]";
   break;
  case 4:
   BodovNaPalec=73.6999749818182; // Fournierov systém
   NazovBodu="Fournierov";
   break;
  case 5:
   BodovNaPalec=69.4302603255113; // Haasov systém
   NazovBodu="Haasov";
   break;
  case 6:
   BodovNaPalec=InyTypoBod.editValue; //iný systém
   NazovBodu="iný";
   break; 
 }
 var Vypis=false;
 try  
 {
  if (NastavID.checkedState==true) {
   app.viewPreferences.pointsPerInch=BodovNaPalec;
   Vypis=true;
  }
  if (vDokumente==true) {
   if (NastavDokument.checkedState==true) {
    app.activeDocument.viewPreferences.pointsPerInch=BodovNaPalec;
    Vypis=true;
   }
  }
 } 
 catch (e) {}
 if (Vypis==true) {
  var Bod=25.4/BodovNaPalec;
  alert('Nastavený '+NazovBodu+' typografický bod ('+Bod+' mm).');
 }
 else {alert('Typografický bod nezmenený.')}
}
DialogNastavBody.destroy();
 